@@ -1,4 +1,4 @@
-/* $Id: blast_returns.c,v 1.29 2006/04/26 12:46:00 madden Exp $
+/* $Id: blast_returns.c,v 1.38 2007/07/10 15:28:07 papadopo Exp $
 * ===========================================================================
 *
 *                            PUBLIC DOMAIN NOTICE
@@ -28,7 +28,9 @@
  * Manipulating data returned from BLAST other than Seq-aligns
  */
 
-static char const rcsid[] = "$Id: blast_returns.c,v 1.29 2006/04/26 12:46:00 madden Exp $";
+#ifndef SKIP_DOXYGEN_PROCESSING
+static char const rcsid[] = "$Id: blast_returns.c,v 1.38 2007/07/10 15:28:07 papadopo Exp $";
+#endif /* SKIP_DOXYGEN_PROCESSING */
 
 #include <algo/blast/api/blast_returns.h>
 #include <algo/blast/api/blast_seq.h>
@@ -192,8 +194,12 @@ Blast_GetParametersBuffer(EBlastProgramType program_number,
        add_string_to_buffer(buffer, &ret_buffer, &ret_buffer_length);
    }
    if (search_params->threshold) {
-       sprintf(buffer, "Neighboring words threshold: %ld", 
-               (long) search_params->threshold);
+       if (search_params->threshold == floor(search_params->threshold))
+           sprintf(buffer, "Neighboring words threshold: %ld", 
+                   (long)search_params->threshold);
+       else
+           sprintf(buffer, "Neighboring words threshold: %.2f", 
+                   search_params->threshold);
        add_string_to_buffer(buffer, &ret_buffer, &ret_buffer_length);
    }
    if (search_params->window_size) {
@@ -364,10 +370,9 @@ s_SummaryDBStatsFill(EBlastProgramType program_number,
          itr = BlastSeqSrcIteratorFree(itr);
       }
    }
-      
-   if (program_number == eBlastTypeTblastn || 
-       program_number == eBlastTypeRpsTblastn ||
-       program_number == eBlastTypeTblastx)
+
+   if (Blast_SubjectIsTranslated(program_number) ||
+       program_number == eBlastTypeRpsTblastn)
       total_length /= 3;
 
    (*db_stats)->dblength = total_length;
@@ -381,6 +386,7 @@ s_SummaryDBStatsFill(EBlastProgramType program_number,
    (*db_stats)->dbnum = num_entries;
 
    if (program_number == eBlastTypeBlastx ||
+       program_number == eBlastTypeRpsTblastn ||
        program_number == eBlastTypeTblastx)
       num_frames = NUM_FRAMES;
    else if (program_number == eBlastTypeBlastn ||
@@ -397,12 +403,17 @@ s_SummaryDBStatsFill(EBlastProgramType program_number,
       /** FIXME: Should this be different for RPS BLAST? */
       (*db_stats)->qlen = qlen;
       (*db_stats)->eff_qlen = qlen - ((*db_stats)->hsp_length);
-      (*db_stats)->eff_dblength = 
-          total_length - num_entries*((*db_stats)->hsp_length);
+      (*db_stats)->eff_dblength = total_length;
+      if (eff_len_options->db_length == 0) {
+         (*db_stats)->eff_dblength -= (Int8)num_entries *
+                                        ((*db_stats)->hsp_length);
+      }
       (*db_stats)->eff_searchsp = 
           query_info->contexts[query_info->first_context].eff_searchsp;
-      if (eff_len_options && eff_len_options->searchsp_eff)
-         (*db_stats)->eff_searchsp_used = eff_len_options->searchsp_eff;
+      if (eff_len_options && 
+          eff_len_options->num_searchspaces &&
+          eff_len_options->searchsp_eff[0])
+         (*db_stats)->eff_searchsp_used = eff_len_options->searchsp_eff[0];
       else
          (*db_stats)->eff_searchsp_used = (*db_stats)->eff_searchsp;
    }
@@ -643,8 +654,7 @@ int Blast_SummaryReturnUpdate(const Blast_SummaryReturn* new_return,
     if (new_return->error)
         full_return->error = SBlastMessageDup(new_return->error);
 
-    full_return->pattern_info = (SPHIQueryInfo*)
-        BlastMemDup(new_return->pattern_info, sizeof(SPHIQueryInfo));
+    full_return->pattern_info = SPHIQueryInfoCopy(new_return->pattern_info);
 
     return 0;
 }
