@@ -1,4 +1,4 @@
-/* $Id: blast_parameters.c,v 1.36 2007/05/22 20:55:36 kazimird Exp $
+/* $Id: blast_parameters.c,v 1.38 2007/10/25 15:55:36 kazimird Exp $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -30,7 +30,7 @@
 
 #ifndef SKIP_DOXYGEN_PROCESSING
 static char const rcsid[] = 
-    "$Id: blast_parameters.c,v 1.36 2007/05/22 20:55:36 kazimird Exp $";
+    "$Id: blast_parameters.c,v 1.38 2007/10/25 15:55:36 kazimird Exp $";
 #endif /* SKIP_DOXYGEN_PROCESSING */
 
 #include <algo/blast/core/blast_parameters.h>
@@ -186,6 +186,11 @@ BlastInitialWordParametersNew(EBlastProgramType program_number,
    p = *parameters = (BlastInitialWordParameters*)calloc(1, 
                                      sizeof(BlastInitialWordParameters));
 
+   if (Blast_ProgramIsPhiBlast(program_number))
+      p->ungapped_extension = FALSE;
+   else
+      p->ungapped_extension = TRUE;
+
    p->cutoffs = (BlastUngappedCutoffs *)calloc(
            (size_t)(query_info->last_context+1), sizeof(BlastUngappedCutoffs));
 
@@ -665,13 +670,14 @@ BlastHitSavingParametersNew(EBlastProgramType program_number,
    if (params == NULL)
       return 1;
 
+   params->do_sum_stats = options->do_sum_stats;
    params->options = (BlastHitSavingOptions *) options;
    /* Each context gets its own gapped cutoff data */
    params->cutoffs = (BlastGappedCutoffs *)calloc(
                                         (size_t)(query_info->last_context+1),
                                         sizeof(BlastGappedCutoffs));
 
-   if (options->do_sum_stats) {
+   if (params->do_sum_stats) {
       BlastLinkHSPParametersNew(program_number, gapped_calculation,
                                 &params->link_hsp_params);
 
@@ -695,6 +701,7 @@ BlastHitSavingParametersNew(EBlastProgramType program_number,
                   /* A nonpositive value of max_protein_gap disables linking */
                   params->link_hsp_params =
                       BlastLinkHSPParametersFree(params->link_hsp_params);
+                  params->do_sum_stats = FALSE;
               } else { /* the value of max_protein_gap is positive */
                   params->link_hsp_params->longest_intron = max_protein_gap;
               }
@@ -940,6 +947,9 @@ CalculateLinkHSPCutoffs(EBlastProgramType program, BlastQueryInfo* query_info,
  * ===========================================================================
  *
  * $Log: blast_parameters.c,v $
+ * Revision 1.38  2007/10/25 15:55:36  kazimird
+ * Synchronized with the C++ Toolkit.
+ *
  * Revision 1.36  2007/05/22 20:55:36  kazimird
  * Synchronized with the C++ Toolkit.
  *
