@@ -1,4 +1,4 @@
-/*  $Id: blast_psi_priv.h,v 1.33 2006/11/22 15:35:17 papadopo Exp $
+/*  $Id: blast_psi_priv.h,v 1.34 2007/12/07 18:25:42 kazimird Exp $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -347,6 +347,8 @@ _PSISequenceWeightsFree(_PSISequenceWeights* seq_weights);
 #define PSIERR_STARTINGGAP      (-10)
 /** Found flanking gap at end of alignment */
 #define PSIERR_ENDINGGAP        (-11)
+/** Unknown error */
+#define PSIERR_UNKNOWN          (-255)
 
 /****************************************************************************/
 /* Function prototypes for the various stages of the PSSM generation engine */
@@ -412,6 +414,8 @@ _PSIComputeSequenceWeights(const _PSIMsa* msa,
  * @param aligned_blocks data structure describing the aligned blocks'
  * properties for each position of the multiple sequence alignment [in]
  * @param pseudo_count pseudo count constant [in]
+ * @param nsg_compatibility_mode set to true to emulate the structure group's
+ * use of PSSM engine in the cddumper application. By default should be FALSE
  * @param internal_pssm PSSM being computed [out]
  * @return PSIERR_BADPARAM if arguments are NULL, PSI_SUCCESS otherwise
  */
@@ -421,6 +425,7 @@ _PSIComputeFreqRatios(const _PSIMsa* msa,
                       const BlastScoreBlk* sbp,
                       const _PSIAlignedBlock* aligned_blocks,
                       Int4 pseudo_count,
+                      Boolean nsg_compatibility_mode,
                       _PSIInternalPssmData* internal_pssm);
 
 /** Converts the PSSM's frequency ratios obtained in the previous stage to a 
@@ -625,126 +630,4 @@ _PSIValidateMSA_StructureGroup(const _PSIMsa* msa);
 }
 #endif
 
-
-/*
- * ===========================================================================
- *
- * $Log: blast_psi_priv.h,v $
- * Revision 1.33  2006/11/22 15:35:17  papadopo
- * doxygen fixes
- *
- * Revision 1.32  2006/11/21 17:07:38  papadopo
- * rearrange headers
- *
- * Revision 1.31  2006/11/14 15:37:19  camacho
- * PSSM engine performance optimizations
- *
- * Revision 1.30  2006/04/19 19:16:49  camacho
- * Refactoring of structure group customization and addition of validation
- *
- * Revision 1.29  2005/05/24 12:49:24  camacho
- * doxygen fix
- *
- * Revision 1.28  2005/05/10 16:07:51  camacho
- * Changed *_ENCODING #defines to EBlastEncoding enumeration
- *
- * Revision 1.27  2005/03/23 14:04:24  camacho
- * doxygen fix
- *
- * Revision 1.26  2005/03/22 15:35:10  camacho
- * Fix to enable backwards compatibility with old PSSM engine when the query is
- * the only sequence aligned for a given column of the multiple sequence
- * alignment.
- *
- * Revision 1.25  2005/02/28 13:40:11  camacho
- * Minor doxygen fix
- *
- * Revision 1.24  2005/02/23 17:24:41  camacho
- * 1. Moved prototype of _PSIUpdateLambdaK to blast_psi_priv.h
- * 2. Removed unneeded fields from Kappa_compactSearchItems
- * 3. Doxygen fixes
- *
- * Revision 1.23  2005/02/22 22:49:34  camacho
- * + impala_scaling_factor, first cut
- *
- * Revision 1.22  2005/01/31 16:50:21  camacho
- * 1. Moved constants to private header.
- * 2. Changed signature of functions to copy matrices.
- *
- * Revision 1.21  2004/12/13 22:26:59  camacho
- * Consolidated structure group customizations in option: nsg_compatibility_mode
- *
- * Revision 1.20  2004/12/08 15:06:02  camacho
- * Call _PSIUpdatePositionCounts is needed after purging query sequence for
- * structure group customization, thus this function has been changed to reset the
- * appropriate _PSIMsa fields so that residue counts/aligned sequences are
- * reported accurately.
- *
- * Revision 1.19  2004/12/07 22:07:34  camacho
- * Add sanity checks for purge identity threshold
- *
- * Revision 1.18  2004/11/26 14:22:54  camacho
- * doxygen fixes
- *
- * Revision 1.17  2004/11/22 14:38:48  camacho
- * + option to set % identity threshold to PSSM engine
- *
- * Revision 1.16  2004/11/18 16:25:32  camacho
- * Rename _PSIGetStandardProbabilities to BLAST_GetStandardAaProbabilities
- *
- * Revision 1.15  2004/11/02 20:37:30  camacho
- * Doxygen fixes
- *
- * Revision 1.14  2004/10/18 14:33:14  camacho
- * 1. Added validation routines
- * 2. Fixed bug in calculating sequence weights
- * 3. Expanded error codes
- *
- * Revision 1.13  2004/08/31 16:13:28  camacho
- * Documentation changes
- *
- * Revision 1.12  2004/08/04 20:18:26  camacho
- * 1. Renaming of structures and functions that pertain to the internals of PSSM
- *    engine.
- * 2. Updated documentation (in progress)
- *
- * Revision 1.11  2004/08/02 13:25:49  camacho
- * 1. Various renaming of structures, in progress
- * 2. Addition of PSIDiagnostics structures, in progress
- *
- * Revision 1.10  2004/07/29 19:16:02  camacho
- * Moved PSIExtractQuerySequenceInfo
- *
- * Revision 1.9  2004/07/22 19:05:58  camacho
- * 1. Removed information content from _PSISequenceWeights structure.
- * 2. Added functions to calculate information content.
- *
- * Revision 1.8  2004/07/02 17:57:57  camacho
- * Made _PSIUpdatePositionCounts non-static
- *
- * Revision 1.7  2004/06/21 12:52:44  camacho
- * Replace PSI_ALPHABET_SIZE for BLASTAA_SIZE
- *
- * Revision 1.6  2004/06/17 20:46:59  camacho
- * doxygen fixes
- *
- * Revision 1.5  2004/06/09 14:20:30  camacho
- * Updated comments
- *
- * Revision 1.4  2004/05/28 16:00:10  camacho
- * + first port of PSSM generation engine
- *
- * Revision 1.3  2004/05/06 14:01:40  camacho
- * + _PSICopyDoubleMatrix
- *
- * Revision 1.2  2004/04/07 21:43:47  camacho
- * Removed unneeded #include directive
- *
- * Revision 1.1  2004/04/07 19:11:17  camacho
- * Initial revision
- *
- *
- * ===========================================================================
- */
-
 #endif /* !ALGO_BLAST_CORE__BLAST_PSI_PRIV__H */
