@@ -29,7 +29,7 @@
 *
 * Version Creation Date: 3/4/91
 *
-* $Revision: 6.4 $
+* $Revision: 6.7 $
 *
 * File Description:
 *   Special binary form (BER) decoder for ASN.1
@@ -45,6 +45,15 @@
 * 08-01-93 Gish        AsnDeBinReadString calls MemGet instead of MemNew
 *
 * $Log: asndebin.c,v $
+* Revision 6.7  2004/04/01 13:43:05  lavr
+* Spell "occurred", "occurrence", and "occurring"
+*
+* Revision 6.6  2003/12/10 15:41:19  sirotkin
+* As per toolkit RT request 15030485 and Jim Ostell, afety checks after ato2=AsnFindBaseIsa(atp) were added.
+*
+* Revision 6.5  2002/10/09 19:16:31  ivanov
+* Fixed buffer overrun in the AsnDeBinReadReal()
+*
 * Revision 6.4  2000/12/12 15:56:10  ostell
 * added support BigInt
 *
@@ -115,9 +124,15 @@ NLM_EXTERN AsnTypePtr LIBCALL  AsnBinReadId (AsnIoPtr aip, AsnTypePtr atp)
 
 		if (used == ASNDEBIN_EOF)      /* end of file */
 			return NULL;
+                /* see RT toolbox ticket 15030485 for the below fix */
 
 		atp2 = AsnFindBaseType(atp);   /* find the base type */
-		if (atp2 == NULL) return NULL;
+		if (atp2 == NULL)
+			return atp2;
+		if (atp2->type == NULL)
+			return atp2->type;
+		isa = atp2->type->isa;
+
 
 		if (atp2->type->isa != CHOICE_TYPE)
 		{
@@ -527,7 +542,7 @@ NLM_EXTERN Int4 AsnDeBinScanTag (AsnIoPtr aip)
 *   	returns START_STRUCT
 *               END_STRUCT
 *   			1 if ok
-*   			0 if an error occured
+*   			0 if an error occurred
 *   	if (valueptr == NULL)
 *   		just checks that value is of proper type
 *
@@ -1200,7 +1215,7 @@ NLM_EXTERN FloatHi AsnDeBinReadReal (AsnIoPtr aip)
 	Int4 len;
 	Int2 bytes, amount;
 	BytePtr bp;
-	char buf[30], *tmp;
+	char buf[200], *tmp;
 
 	aip->tagsaved = FALSE;
 	len = aip->length;
