@@ -1,7 +1,7 @@
 #ifndef CONNECT___NCBI_ANSI_EXT__H
 #define CONNECT___NCBI_ANSI_EXT__H
 
-/*  $Id: ncbi_ansi_ext.h,v 6.12 2004/03/12 23:25:37 gorelenk Exp $
+/*  $Id: ncbi_ansi_ext.h,v 6.15 2006/03/07 18:14:59 lavr Exp $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -54,11 +54,27 @@ extern "C" {
  * Return an identical malloc'ed string, which must be explicitly freed 
  * by free() when no longer needed.
  */
-extern char* strdup(const char* str);
+extern NCBI_XCONNECT_EXPORT char* strdup(const char* str);
 
 #endif /*HAVE_STRDUP*/
 
 
+#ifndef HAVE_STRNDUP
+
+#  ifdef strndup
+#    undef strndup
+#  endif
+#  define strndup     NCBI_strndup
+
+/* Create a copy of up to "n" first characters of string "str".
+ * Return a malloc'ed and '\0'-terminated string, which must be
+ * explicitly freed by free() when no longer needed.
+ */
+extern NCBI_XCONNECT_EXPORT char* strndup(const char* str, size_t n);
+
+#endif /*HAVE_STRNDUP*/
+
+
 #ifndef HAVE_STRCASECMP
 
 #  ifdef strcasecmp
@@ -87,8 +103,8 @@ extern NCBI_XCONNECT_EXPORT int strncasecmp(const char* s1, const char* s2, size
 #  undef strupr
 #  undef strlwr
 #endif
-#define strupr NCBI_strupr
-#define strlwr NCBI_strlwr
+#define strupr        NCBI_strupr
+#define strlwr        NCBI_strlwr
 
 /* Convert a string to uppercase, then return pointer to
  * the altered string. Because the conversion is made in place, the
@@ -106,8 +122,8 @@ extern NCBI_XCONNECT_EXPORT char* strlwr(char* s);
 /* Copy not more than "n" characters from string "s2" into "s1"
  * and return the result, which is always null-terminated.
  * NOTE: The difference of this function from standard strncpy() is in
- * that the result is always null-terminated and that the function
- * does not pad "s1" with null bytes should "s2" be shorter than "n".
+ * that the result is always null-terminated and that the function does not
+ * pad "s1" with null bytes should "s2" be shorter than "n" characters.
  */
 extern NCBI_XCONNECT_EXPORT char* strncpy0(char* s1, const char* s2, size_t n);
 
@@ -120,6 +136,15 @@ extern NCBI_XCONNECT_EXPORT char* strncpy0(char* s1, const char* s2, size_t n);
 /*
  * --------------------------------------------------------------------------
  * $Log: ncbi_ansi_ext.h,v $
+ * Revision 6.15  2006/03/07 18:14:59  lavr
+ * Formatting
+ *
+ * Revision 6.14  2006/03/07 17:18:52  lavr
+ * +strndup
+ *
+ * Revision 6.13  2005/04/20 18:12:16  lavr
+ * strdup() has got NCBI_XCONNECT_EXPORT
+ *
  * Revision 6.12  2004/03/12 23:25:37  gorelenk
  * Added export prefixes.
  *
