@@ -1,4 +1,4 @@
-/*  $Id: ncbi_connection.c,v 6.48 2006/02/23 17:43:01 lavr Exp $
+/*  $Id: ncbi_connection.c,v 6.49 2007/10/17 15:25:43 kazimird Exp $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -42,35 +42,39 @@
  *  INTERNAL
  ***********************************************************************/
 
+#define NCBI_USE_ERRCODE_X   Connect_Connection
+
 
 /* Standard logging message
  */
-#define CONN_LOG_EX(level, descr, status)                  \
-  CORE_LOGF(level,                                         \
+#define CONN_LOG_EX(subcode, level, descr, status)         \
+  CORE_LOGF_X(subcode, level,                                \
             ("%s (connector \"%s\", error \"%s\")", descr, \
              conn->meta.get_type                           \
              ? conn->meta.get_type(conn->meta.c_get_type)  \
              : "Unknown", IO_StatusStr(status)))
 
-#define CONN_LOG(level, descr)  CONN_LOG_EX(level, descr, status)
+#define CONN_LOG(subcode, level, descr)   \
+    CONN_LOG_EX(subcode, level, descr, status)
+
 #ifdef _DEBUG
-#  define CONN_TRACE(descr)  CONN_LOG(eLOG_Trace, descr)
+#  define CONN_TRACE(descr)  CONN_LOG(0, eLOG_Trace, descr)
 #else
 #  define CONN_TRACE(descr)  ((void) 0)
 #endif /*_DEBUG*/
 
 /* Standard macros to verify that the passed connection handle is not NULL
  */
-#define CONN_NOT_NULL_EX(func_name, status)                     \
+#define CONN_NOT_NULL_EX(subcode, func_name, status)            \
   if ( !conn ) {                                                \
-      CORE_LOG(eLOG_Error, "CONN_" #func_name                   \
+      CORE_LOG_X(subcode, eLOG_Error, "CONN_" #func_name          \
                "(conn, ...) -- passed NULL connection handle"); \
       assert(conn);                                             \
       return status;                                            \
   }
 
-#define CONN_NOT_NULL(func_name)              \
-  CONN_NOT_NULL_EX(func_name, eIO_InvalidArg)
+#define CONN_NOT_NULL(subcode, func_name)   \
+  CONN_NOT_NULL_EX(subcode, func_name, eIO_InvalidArg)
 
 
 /* Connection state
@@ -82,10 +86,11 @@ typedef enum ECONN_StateTag {
 } ECONN_State;
 
 
-/* Connection internal data
+/* Connection internal data:  meta *must* come first
  */
 typedef struct SConnectionTag {
     SMetaConnector         meta;       /* VTable of operations and list      */
+
     BUF                    buf;        /* storage for the Peek'd data        */
 #ifdef IMPLEMENTED__CONN_WaitAsync
     SConnectorAsyncHandler async_data; /* info of curr. async event handler  */
@@ -143,13 +148,13 @@ extern EIO_Status CONN_ReInit
     CONNECTOR  x_conn = 0;
     EIO_Status status;
 
-    CONN_NOT_NULL(ReInit);
+    CONN_NOT_NULL(1, ReInit);
 
     /* check arg */
     if (!connector  &&  !conn->meta.list) {
         assert(conn->state == eCONN_Unusable);
         status = eIO_Unknown;
-        CONN_LOG(eLOG_Error,
+        CONN_LOG(2, eLOG_Error,
                  "[CONN_ReInit]  Cannot re-init empty connection with NULL");
         return status;
     }
@@ -177,7 +182,7 @@ extern EIO_Status CONN_ReInit
                                           ? conn->meta.default_timeout
                                           : conn->c_timeout);
                 if (status != eIO_Success) {
-                    CONN_LOG(connector ? eLOG_Error : eLOG_Warning,
+                    CONN_LOG(3, connector ? eLOG_Error : eLOG_Warning,
                              "[CONN_ReInit]  Cannot close current connection");
                     if (connector)
                         return status;
@@ -192,7 +197,7 @@ extern EIO_Status CONN_ReInit
                 if (!x_conn->next  &&  x_conn == conn->meta.list)
                     break;
                 status = eIO_Unknown;
-                CONN_LOG(eLOG_Error,
+                CONN_LOG(4, eLOG_Error,
                          "[CONN_ReInit]  Partial re-init not allowed");
                 return status;
             }
@@ -235,7 +240,7 @@ static EIO_Status s_Open
         : eIO_NotSupported;
 
     if (status != eIO_Success) {
-        CONN_LOG(eLOG_Error, "[CONN_Open]  Cannot open connection");
+        CONN_LOG(5, eLOG_Error, "[CONN_Open]  Cannot open connection");
         return status;
     }
 
@@ -247,7 +252,7 @@ static EIO_Status s_Open
 
 extern const char* CONN_GetType(CONN conn)
 {
-    CONN_NOT_NULL_EX(GetType, 0);
+    CONN_NOT_NULL_EX(6, GetType, 0);
 
     return conn->state == eCONN_Unusable  ||  !conn->meta.list  ||
         !conn->meta.get_type ? 0 : conn->meta.get_type(conn->meta.c_get_type);
@@ -256,7 +261,7 @@ extern const char* CONN_GetType(CONN conn)
 
 extern char* CONN_Description(CONN conn)
 {
-    CONN_NOT_NULL_EX(Description, 0);
+    CONN_NOT_NULL_EX(7, Description, 0);
 
     return conn->state == eCONN_Unusable  ||  !conn->meta.list  ||
         !conn->meta.descr ? 0 : conn->meta.descr(conn->meta.c_descr);
@@ -270,7 +275,7 @@ extern EIO_Status CONN_SetTimeout
 {
     EIO_Status status = eIO_Success;
 
-    CONN_NOT_NULL(SetTimeout);
+    CONN_NOT_NULL(8, SetTimeout);
 
     switch (event) {
     case eIO_Open:
@@ -314,7 +319,7 @@ extern EIO_Status CONN_SetTimeout
         break;
     default:
         status = eIO_InvalidArg;
-        CONN_LOG(eLOG_Error,
+        CONN_LOG(9, eLOG_Error,
                  "[CONN_SetTimeout]  Unknown event to set timeout for");
         assert(0);
         break;
@@ -328,13 +333,13 @@ extern const STimeout* CONN_GetTimeout
 (CONN      conn,
  EIO_Event event)
 {
-    CONN_NOT_NULL_EX(GetTimeout, 0);
+    CONN_NOT_NULL_EX(10, GetTimeout, 0);
 
     switch (event) {
     case eIO_Open:
         return conn->o_timeout;
     case eIO_ReadWrite:
-        CONN_LOG_EX(eLOG_Warning,
+        CONN_LOG_EX(11, eLOG_Warning,
                     "[CONN_GetTimeout]  ReadWrite timeout requested",
                     eIO_InvalidArg);
         /*FALLTHRU*/
@@ -345,7 +350,7 @@ extern const STimeout* CONN_GetTimeout
     case eIO_Close:
         return conn->c_timeout;
     default:
-        CONN_LOG_EX(eLOG_Error,
+        CONN_LOG_EX(12, eLOG_Error,
                     "[CONN_GetTimeout]  Unknown event to get timeout for",
                     eIO_InvalidArg);
         assert(0);
@@ -362,7 +367,7 @@ extern EIO_Status CONN_Wait
 {
     EIO_Status status;
 
-    CONN_NOT_NULL(Wait);
+    CONN_NOT_NULL(13, Wait);
 
     if (conn->state == eCONN_Unusable               ||
         (event != eIO_Read  &&  event != eIO_Write) ||
@@ -385,9 +390,9 @@ extern EIO_Status CONN_Wait
 
     if (status != eIO_Success) {
         if (status != eIO_Timeout)
-            CONN_LOG(eLOG_Error, "[CONN_Wait]  Error waiting on I/O");
+            CONN_LOG(14, eLOG_Error, "[CONN_Wait]  Error waiting on I/O");
         else if (!timeout || timeout->sec || timeout->usec)
-            CONN_LOG(eLOG_Warning, "[CONN_Wait]  I/O timed out");
+            CONN_LOG(15, eLOG_Warning, "[CONN_Wait]  I/O timed out");
     }
 
     return status;
@@ -407,7 +412,7 @@ static EIO_Status s_CONN_Write
     /* check if the write method is specified at all */
     if ( !conn->meta.write ) {
         status = eIO_NotSupported;
-        CONN_LOG(eLOG_Error, "[CONN_Write]  Unable to write data");
+        CONN_LOG(16, eLOG_Error, "[CONN_Write]  Unable to write data");
         return status;
     }
 
@@ -421,7 +426,7 @@ static EIO_Status s_CONN_Write
             CONN_TRACE("[CONN_Write]  Write error");
             status = eIO_Success;
         } else if ( size )
-            CONN_LOG(eLOG_Error, "[CONN_Write]  Cannot write data");
+            CONN_LOG(17, eLOG_Error, "[CONN_Write]  Cannot write data");
     }
     return status;
 }
@@ -464,7 +469,7 @@ extern EIO_Status CONN_Write
     *n_written = 0;
     if (size  &&  !buf)
         return eIO_InvalidArg;
-    CONN_NOT_NULL(Write);
+    CONN_NOT_NULL(18, Write);
 
     if (conn->state == eCONN_Unusable)
         return eIO_InvalidArg;
@@ -491,7 +496,7 @@ extern EIO_Status CONN_PushBack
  const void* buf,
  size_t      size)
 {
-    CONN_NOT_NULL(PushBack);
+    CONN_NOT_NULL(19, PushBack);
 
     if (conn->state != eCONN_Open)
         return eIO_InvalidArg;
@@ -505,7 +510,7 @@ extern EIO_Status CONN_Flush
 {
     EIO_Status status;
 
-    CONN_NOT_NULL(Flush);
+    CONN_NOT_NULL(20, Flush);
 
     if (conn->state == eCONN_Unusable)
         return eIO_InvalidArg;
@@ -522,7 +527,7 @@ extern EIO_Status CONN_Flush
                               conn->w_timeout == kDefaultTimeout ?
                               conn->meta.default_timeout : conn->w_timeout);
     if (status != eIO_Success)
-        CONN_LOG(eLOG_Warning, "[CONN_Flush]  Cannot flush data");
+        CONN_LOG(21, eLOG_Warning, "[CONN_Flush]  Cannot flush data");
     return status;
 }
 
@@ -543,7 +548,7 @@ static EIO_Status s_CONN_Read
     /* check if the read method is specified at all */
     if ( !conn->meta.read ) {
         status = eIO_NotSupported;
-        CONN_LOG(eLOG_Error, "[CONN_Read]  Unable to read data");
+        CONN_LOG(22, eLOG_Error, "[CONN_Read]  Unable to read data");
         return status;
     }
 
@@ -573,7 +578,7 @@ static EIO_Status s_CONN_Read
             CONN_TRACE("[CONN_Read]  Read error");
             status = eIO_Success;
         } else if (size  &&  status != eIO_Closed) {
-            CONN_LOG(status == eIO_Timeout ? eLOG_Warning : eLOG_Error,
+            CONN_LOG(23, status == eIO_Timeout ? eLOG_Warning : eLOG_Error,
                      "[CONN_Read]  Cannot read data");
         }
     }
@@ -627,7 +632,7 @@ extern EIO_Status CONN_Read
     if (size  &&  !buf)
         return eIO_InvalidArg;
 
-    CONN_NOT_NULL(Read);
+    CONN_NOT_NULL(24, Read);
 
     if (conn->state == eCONN_Unusable)
         return eIO_InvalidArg;
@@ -676,7 +681,7 @@ extern EIO_Status CONN_ReadLine
     if (size  &&  !line)
         return eIO_InvalidArg;
 
-    CONN_NOT_NULL(ReadLine);
+    CONN_NOT_NULL(25, ReadLine);
 
     /* perform open, if not opened yet */
     if (conn->state != eCONN_Open)
@@ -728,7 +733,7 @@ extern EIO_Status CONN_ReadLine
 
 extern EIO_Status CONN_Status(CONN conn, EIO_Event dir)
 {
-    CONN_NOT_NULL(Status);
+    CONN_NOT_NULL(26, Status);
 
     if (conn->state == eCONN_Unusable  ||  !conn->meta.list)
         return eIO_Unknown;
@@ -751,7 +756,7 @@ extern EIO_Status CONN_Close(CONN conn)
     FConnCallback func = 0;
     void*         data = 0;
 
-    CONN_NOT_NULL(Close);
+    CONN_NOT_NULL(27, Close);
 
     if (conn->state != eCONN_Unusable) {
         func = conn->cbs[eCONN_OnClose].func;
@@ -782,7 +787,7 @@ extern EIO_Status CONN_SetCallback
     if (i >= CONN_N_CALLBACKS)
         return eIO_InvalidArg;
 
-    CONN_NOT_NULL(SetCallback);
+    CONN_NOT_NULL(28, SetCallback);
 
     if ( old_cb )
         *old_cb = conn->cbs[i];
@@ -819,7 +824,7 @@ extern EIO_Status CONN_WaitAsync
     CONNECTOR  x_connector = conn->connector;
     SConnectorAsyncHandler* x_data = &conn->async_data;
 
-    CONN_NOT_NULL(WaitAsync);
+    CONN_NOT_NULL(29, WaitAsync);
 
     /* perform connect, if not connected yet */
     if (!conn->connected  &&  (status = s_Connect(conn)) != eIO_Success)
@@ -831,7 +836,7 @@ extern EIO_Status CONN_WaitAsync
         x_connector->vtable.wait_async(x_connector->handle, 0, 0) :
         eIO_NotSupported;
     if (status != eIO_Success) {
-        CONN_LOG(eLOG_Error, "[CONN_WaitAsync]  Cannot reset the handler");
+        CONN_LOG(30, eLOG_Error, "[CONN_WaitAsync]  Cannot reset the handler");
         return status;
     }
     if ( x_data->cleanup )
@@ -852,178 +857,8 @@ extern EIO_Status CONN_WaitAsync
     status = x_connector->vtable.wait_async(x_connector->handle,
                                             s_ConnectorAsyncHandler, x_data);
     if (status != eIO_Success) {
-        CONN_LOG(eLOG_Error, "[CONN_WaitAsync]  Cannot set new handler");
+        CONN_LOG(31, eLOG_Error, "[CONN_WaitAsync]  Cannot set new handler");
     }
     return status;
 }
 #endif /* IMPLEMENTED__CONN_WaitAsync */
-
-
-/*
- * --------------------------------------------------------------------------
- * $Log: ncbi_connection.c,v $
- * Revision 6.48  2006/02/23 17:43:01  lavr
- * CONN_Read():  No CLOSED trace on EOF
- *
- * Revision 6.47  2006/02/14 15:49:42  lavr
- * Introduce and use CORE_TRACE macros (NOP in Release mode)
- *
- * Revision 6.46  2006/01/18 03:38:17  lavr
- * Prevent copying STimeout structs into themselves [where can occur]
- *
- * Revision 6.45  2005/05/18 18:15:21  lavr
- * Formatting spot
- *
- * Revision 6.44  2004/11/15 19:33:42  lavr
- * Speed-up CONN_ReadLine()
- *
- * Revision 6.43  2004/11/15 17:39:26  lavr
- * Fix CONN_ReadLine() to always perform connector's read method
- *
- * Revision 6.42  2004/05/26 16:00:06  lavr
- * Minor status fixes in CONN_SetTimeout() and CONN_ReadLine()
- *
- * Revision 6.41  2004/05/24 20:19:19  lavr
- * Fix eIO_InvalidArg conditions (size and no buffer)
- *
- * Revision 6.40  2004/05/24 19:54:59  lavr
- * +CONN_ReadLine()
- *
- * Revision 6.39  2004/03/23 02:27:37  lavr
- * Code formatting
- *
- * Revision 6.38  2004/02/23 15:23:39  lavr
- * New (last) parameter "how" added in CONN_Write() API call
- *
- * Revision 6.37  2003/08/25 14:40:53  lavr
- * Employ new k..Timeout constants
- *
- * Revision 6.36  2003/05/31 05:18:26  lavr
- * Optimize on calling flush; do not require to have flush method
- *
- * Revision 6.35  2003/05/21 17:53:06  lavr
- * Better check for {0,0} timeout in CONN_Read()
- *
- * Revision 6.34  2003/05/20 21:21:45  lavr
- * CONN_Write(): log with different log levels on write errors
- *
- * Revision 6.33  2003/05/19 16:43:40  lavr
- * Bugfix in CONN_SetTimeout();  better close callback sequence
- *
- * Revision 6.32  2003/05/14 03:51:16  lavr
- * +CONN_Description()
- *
- * Revision 6.31  2003/05/12 18:33:21  lavr
- * Names of timeout variables uniformed
- *
- * Revision 6.30  2003/01/28 15:16:37  lavr
- * Fix "NULL" message not to contain double quotes in call names
- *
- * Revision 6.29  2003/01/17 19:44:46  lavr
- * Reduce dependencies
- *
- * Revision 6.28  2003/01/15 19:51:17  lavr
- * +CONN_PushBack()
- *
- * Revision 6.27  2002/09/19 19:43:46  lavr
- * Add more assert()'s and do not rely on CONN_Flush() to open in CONN_Read()
- *
- * Revision 6.26  2002/09/06 15:43:20  lavr
- * Bug fixes of late assignments in Read and Write; Flush changed to open
- * connection if not yet open; more error logging
- *
- * Revision 6.25  2002/08/07 16:32:32  lavr
- * Changed EIO_ReadMethod enums accordingly; log moved to end
- *
- * Revision 6.24  2002/04/26 16:30:26  lavr
- * Checks for kDefaultTimeout and use of default_timeout of meta-connector
- *
- * Revision 6.23  2002/04/24 21:18:04  lavr
- * Beautifying: move open check in front of buffer check in CONN_Wait()
- *
- * Revision 6.22  2002/04/22 19:30:01  lavr
- * Do not put trace message on polling wait (tmo={0,0})
- * More effective CONN_Read w/o repeatitive checkings for eIO_ReadPersist
- *
- * Revision 6.21  2002/03/22 22:17:01  lavr
- * Better check when formally timed out but technically polled in CONN_Wait()
- *
- * Revision 6.20  2002/02/05 22:04:12  lavr
- * Included header files rearranged
- *
- * Revision 6.19  2002/01/30 20:10:56  lavr
- * Remove *n_read = 0 assignment in s_CONN_Read; replace it with assert()
- *
- * Revision 6.18  2001/08/20 20:13:15  vakatov
- * CONN_ReInit() -- Check connection handle for NULL (it was missed in R6.17)
- *
- * Revision 6.17  2001/08/20 20:00:43  vakatov
- * CONN_SetTimeout() to return "EIO_Status".
- * CONN_***() -- Check connection handle for NULL.
- *
- * Revision 6.16  2001/07/10 15:08:35  lavr
- * Edit for style
- *
- * Revision 6.15  2001/06/29 21:06:46  lavr
- * BUGFIX: CONN_LOG now checks for non-NULL get_type virtual function
- *
- * Revision 6.14  2001/06/28 22:00:48  lavr
- * Added function: CONN_SetCallback
- * Added callback: eCONN_OnClose
- *
- * Revision 6.13  2001/06/07 17:54:36  lavr
- * Modified exit branch in s_CONN_Read()
- *
- * Revision 6.12  2001/05/30 19:42:44  vakatov
- * s_CONN_Read() -- do not issue warning if requested zero bytes
- * (by A.Lavrentiev)
- *
- * Revision 6.11  2001/04/24 21:29:04  lavr
- * kDefaultTimeout is used everywhere when timeout is not set explicitly
- *
- * Revision 6.10  2001/02/26 22:52:44  kans
- * Initialize x_read in s_CONN_Read
- *
- * Revision 6.9  2001/02/26 16:32:01  kans
- * Including string.h instead of cstring
- *
- * Revision 6.8  2001/02/25 21:41:50  kans
- * Include <cstring> on Mac to get memset
- *
- * Revision 6.7  2001/02/09 17:34:18  lavr
- * CONN_GetType added; severities of some messages changed
- *
- * Revision 6.6  2001/01/25 16:55:48  lavr
- * CONN_ReInit bugs fixed
- *
- * Revision 6.5  2001/01/23 23:10:53  lavr
- * Typo corrected in description of connection structure
- *
- * Revision 6.4  2001/01/12 23:51:38  lavr
- * Message logging modified for use LOG facility only
- *
- * Revision 6.3  2001/01/03 22:29:59  lavr
- * CONN_Status implemented
- *
- * Revision 6.2  2000/12/29 17:52:59  lavr
- * Adapted to use new connector structure; modified to have
- * an internal tri-state {Unusable | Open | Closed }.
- *
- * Revision 6.1  2000/03/24 22:53:34  vakatov
- * Initial revision
- *
- * Revision 6.4  1999/11/01 16:14:23  vakatov
- * s_CONN_Read() -- milder error levels when hitting EOF
- *
- * Revision 6.3  1999/04/05 15:32:53  vakatov
- * CONN_Wait():  be more mild and discrete about the posted error severity
- *
- * Revision 6.1  1999/04/01 21:48:09  vakatov
- * Fixed for the change in spec:  "n_written/n_read" args in
- * CONN_Write/Read to be non-NULL and "*n_written / *n_read" := 0
- *
- * Revision 6.0  1999/03/25 23:04:57  vakatov
- * Initial revision
- *
- * ==========================================================================
- */
