@@ -1,7 +1,7 @@
 #ifndef CONNECT___NCBI_CONNUTIL__H
 #define CONNECT___NCBI_CONNUTIL__H
 
-/*  $Id: ncbi_connutil.h,v 6.61 2007/01/24 04:23:08 lavr Exp $
+/*  $Id: ncbi_connutil.h,v 6.62 2007/12/05 19:26:19 kazimird Exp $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -62,10 +62,6 @@
  *       URL_Decode()
  *       URL_DecodeEx()
  *
- *    4.Perform BASE64 (RFC 1521) encoding/decoding of data:
- *       BASE64_Encode()
- *       BASE64_Decode()
- *
  *    5.Compose or parse NCBI-specific Content-Type's:
  *       EMIME_Type
  *       EMIME_SubType
@@ -548,49 +544,6 @@ extern NCBI_XCONNECT_EXPORT int/*bool*/ URL_DecodeEx
 
 
 
-/* BASE64-encode up to "src_size" symbols(bytes) from buffer "src_buf".
- * Write the encoded data to buffer "dst_buf", but no more than "dst_size"
- * bytes.
- * Assign "*src_read" to the # of bytes successfully encoded from "src_buf".
- * Assign "*dst_written" to the # of bytes written to buffer "dst_buf".
- * Resulting lines will not exceed "*line_len" (or the standard default
- * if "line_len" is NULL) bytes;  *line_len == 0 disables line breaks.
- * To estimate required destination buffer size, you can take into account
- * that BASE64 coding converts every 3 bytes of source into 4 bytes on
- * destination, not including the line breaks ('\n').
- */
-extern NCBI_XCONNECT_EXPORT void BASE64_Encode
-(const void* src_buf,    /* [in]     non-NULL */
- size_t      src_size,   /* [in]              */
- size_t*     src_read,   /* [out]    non-NULL */
- void*       dst_buf,    /* [in/out] non-NULL */
- size_t      dst_size,   /* [in]              */
- size_t*     dst_written,/* [out]    non-NULL */
- size_t*     line_len    /* [in]  may be NULL */
- );
-
-
-/* BASE64-decode up to "src_size" symbols(bytes) from buffer "src_buf".
- * Write the decoded data to buffer "dst_buf", but no more than "dst_size"
- * bytes.
- * Assign "*src_read" to the # of bytes successfully decoded from "src_buf".
- * Assign "*dst_written" to the # of bytes written to buffer "dst_buf".
- * Return FALSE (0) only if cannot decode anything.
- * Destination buffer size, as a worst case, equal to the source size
- * will accomodate the entire input.  As a rule, each 4 bytes of source
- * (line breaks skipped) are converted into 3 bytes on output.
- */
-extern NCBI_XCONNECT_EXPORT int/*bool*/ BASE64_Decode
-(const void* src_buf,    /* [in]     non-NULL */
- size_t      src_size,   /* [in]              */
- size_t*     src_read,   /* [out]    non-NULL */
- void*       dst_buf,    /* [in/out] non-NULL */
- size_t      dst_size,   /* [in]              */
- size_t*     dst_written /* [out]    non-NULL */
- );
-
-
-
 /****************************************************************************
  * NCBI-specific MIME content type and sub-types
  * (the API to compose and parse them)
@@ -731,209 +684,4 @@ size_t HostPortToString
 
 /* @} */
 
-
-/*
- * --------------------------------------------------------------------------
- * $Log: ncbi_connutil.h,v $
- * Revision 6.61  2007/01/24 04:23:08  lavr
- * Synchronized with the C++ Toolkit.
- *
- * Revision 6.60  2006/10/26 18:54:12  jcherry
- * Added export specifier
- *
- * Revision 6.59  2006/08/14 19:08:41  lavr
- * HTTP_REFERER documented as may have added automatically
- *
- * Revision 6.58  2006/06/15 02:43:59  lavr
- * GetUsername, GetVMPageSize, CRC32 moved from here to ncbi_util.h
- *
- * Revision 6.57  2006/06/07 20:03:46  lavr
- * +SConnNetInfo::http_referer
- *
- * Revision 6.56  2006/04/21 14:41:19  lavr
- * REG_CONN_SERVICE_NAME added
- *
- * Revision 6.55  2006/04/21 01:33:22  lavr
- * SConnNetInfo::lb_disable reinstated along with LB_DISABLE reg/env key
- *
- * Revision 6.53  2006/04/20 13:57:51  lavr
- * Registry keys for new switching scheme for service mappers;
- * Registry keys for LOCAL service mappers
- *
- * Revision 6.52  2006/04/19 02:26:05  lavr
- * Document ConnNetInfo_{Pre|Post}OverrideArg in more details
- *
- * Revision 6.51  2006/02/23 15:46:16  lavr
- * Clean ChangeLog
- *
- * Revision 6.50  2006/02/23 15:22:43  lavr
- * +CONNUTIL_GetVMPageSize()
- *
- * Revision 6.49  2006/01/27 19:17:41  lavr
- * Fix NCBI_DEPRECATED placement to satify MSVC compiler
- *
- * Revision 6.48  2006/01/27 17:08:35  lavr
- * Spell CONNUTIL_GetUsername() this way
- *
- * Revision 6.47  2006/01/27 16:57:53  lavr
- * Obsoleted StringHostToPort() and HostPortToString()
- * Added new CONNUTIL_GetUsername()
- *
- * Revision 6.46  2006/01/11 20:19:56  lavr
- * -UTIL_ClientAddress()
- * +ConnNetInfo_DeleteAllArgs()
- * +ConnNetInfo_SetupStandardArgs()
- *
- * Revision 6.45  2006/01/11 16:24:03  lavr
- * +UTIL_ClientAddress()
- *
- * Revision 6.44  2005/11/29 21:32:07  lavr
- * Reserve SConnNetInfo::scheme, user, and pass for future use
- *
- * Revision 6.43  2005/11/29 19:51:51  lavr
- * +CRC32 (pure C interface; not a ZIP version)
- *
- * Revision 6.42  2005/04/20 15:47:24  lavr
- * DEF_CONN_REQ_METHOD changed to ANY
- *
- * Revision 6.41  2005/03/21 17:04:10  lavr
- * BASE64_{En|De}code buffer size estimation hints added
- *
- * Revision 6.40  2005/03/19 02:13:55  lavr
- * +BASE64_{En|De}code
- *
- * Revision 6.39  2005/02/28 17:23:20  lavr
- * Fix HTTP_USER_HEADER env.var. name ("HTTP" was missing)
- *
- * Revision 6.38  2005/02/24 19:51:24  lavr
- * Document CONN_HTTP_USER_HEADER environment
- *
- * Revision 6.37  2005/02/24 19:00:33  lavr
- * +CONN_HTTP_USER_HEADER
- *
- * Revision 6.36  2004/09/16 16:19:16  lavr
- * Mention [in opening comment summary] that EMIME_Type is defined here
- *
- * Revision 6.35  2004/01/14 18:51:41  lavr
- * +eMIME_XmlSoap
- *
- * Revision 6.34  2004/01/07 19:24:40  lavr
- * Added MIME subtype eMIME_Xml
- *
- * Revision 6.33  2003/09/23 21:00:33  lavr
- * Reorder included header files
- *
- * Revision 6.32  2003/08/25 14:48:50  lavr
- * ConnNetInfo_SetUserHeader():  to return completion status
- *
- * Revision 6.31  2003/05/29 17:56:53  lavr
- * More (clarified) comments for URL_Connect()
- *
- * Revision 6.30  2003/05/20 21:24:01  lavr
- * Limit SConnNetInfo::max_try by reasonable "short" value
- *
- * Revision 6.29  2003/04/09 17:58:47  siyan
- * Added doxygen support
- *
- * Revision 6.28  2003/01/17 19:44:20  lavr
- * Reduce dependencies
- *
- * Revision 6.27  2003/01/08 01:59:32  lavr
- * DLL-ize CONNECT library for MSVC (add NCBI_XCONNECT_EXPORT)
- *
- * Revision 6.26  2002/11/19 19:19:24  lavr
- * +ConnNetInfo_ExtendUserHeader()
- *
- * Revision 6.25  2002/11/12 05:49:47  lavr
- * Expand host names to hold 256 chars (instead of 64)
- *
- * Revision 6.24  2002/10/21 18:30:27  lavr
- * +ConnNetInfo_AppendArg()
- * +ConnNetInfo_PrependArg()
- * +ConnNetInfo_DeleteArg()
- * +ConnNetInfo_PreOverrideArg()
- * +ConnNetInfo_PostOverrideArg()
- *
- * Revision 6.23  2002/10/11 19:41:40  lavr
- * +ConnNetInfo_AppendUserHeader()
- * +ConnNetInfo_OverrideUserHeader()
- * +ConnNetInfo_DeleteUserHeader()
- *
- * Revision 6.22  2002/09/19 18:00:21  lavr
- * Header file guard macro changed; log moved to the end
- *
- * Revision 6.21  2002/05/06 19:07:25  lavr
- * -#include <stdlib>; -ConnNetInfo_Print(); +ConnNetInfo_Log()
- *
- * Revision 6.20  2002/02/20 19:12:03  lavr
- * Swapped eENCOD_Url and eENCOD_None; eENCOD_Unknown introduced
- *
- * Revision 6.19  2001/12/30 19:39:36  lavr
- * +ConnNetInfo_ParseURL()
- *
- * Revision 6.18  2001/09/28 20:45:26  lavr
- * SConnNetInfo::max_try equal to 0 is now treated the same way as equal to 1
- *
- * Revision 6.17  2001/09/19 15:58:37  lavr
- * Cut trailing blanks in blank lines
- *
- * Revision 6.16  2001/09/10 21:14:47  lavr
- * Added functions: StringToHostPort()
- *                  HostPortToString()
- *
- * Revision 6.15  2001/06/01 16:01:58  vakatov
- * MIME_ParseContentTypeEx() -- extended description
- *
- * Revision 6.14  2001/05/29 21:15:42  vakatov
- * + eMIME_Plain
- *
- * Revision 6.13  2001/04/24 21:21:38  lavr
- * Special text value "infinite" accepted as infinite timeout from environment
- *
- * Revision 6.12  2001/03/07 23:00:15  lavr
- * Default value for SConnNetInfo::stateless set to empty (FALSE)
- *
- * Revision 6.11  2001/03/02 20:07:07  lavr
- * Typos fixed
- *
- * Revision 6.10  2001/02/26 16:56:41  vakatov
- * Comment SConnNetInfo.
- *
- * Revision 6.9  2001/01/23 23:06:15  lavr
- * SConnNetInfo.debug_printout converted from boolean to enum
- * BUF_StripToPattern() introduced
- *
- * Revision 6.8  2001/01/11 23:05:13  lavr
- * ConnNetInfo_Create() fully documented
- *
- * Revision 6.7  2001/01/08 23:46:10  lavr
- * REQUEST_METHOD -> REQ_METHOD to be consistent with SConnNetInfo
- *
- * Revision 6.6  2001/01/08 22:47:13  lavr
- * ReqMethod constants changed (to conform to coding standard)
- * ClientMode removed; replaced by 2 booleans: stateless and firewall
- * in SConnInfo structure
- *
- * Revision 6.5  2000/12/29 17:47:46  lavr
- * NCBID stuff removed; ClientMode enum added;
- * ConnNetInfo_SetUserHeader added; http_user_header is now
- * included in ConnInfo structure. ConnNetInfo_Destroy parameter
- * changed to be a pointer (was a double pointer).
- *
- * Revision 6.4  2000/11/07 23:23:15  vakatov
- * In-sync with the C Toolkit "connutil.c:R6.15", "connutil.h:R6.13"
- * (with "eMIME_Dispatch" added).
- *
- * Revision 6.3  2000/10/05 22:39:21  lavr
- * SConnNetInfo modified to contain 'client_mode' instead of just 'firewall'
- *
- * Revision 6.2  2000/09/26 22:01:30  lavr
- * Registry entries changed, HTTP request method added
- *
- * Revision 6.1  2000/03/24 22:52:48  vakatov
- * Initial revision
- *
- * ==========================================================================
- */
-
 #endif /* CONNECT___NCBI_CONNUTIL__H */
