@@ -1,7 +1,7 @@
 #ifndef CONNECT___NCBI_CORE__H
 #define CONNECT___NCBI_CORE__H
 
-/* $Id: ncbi_core.h,v 6.31 2007/06/25 15:25:32 kazimird Exp $
+/* $Id: ncbi_core.h,v 6.33 2007/10/17 15:25:43 kazimird Exp $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -313,6 +313,10 @@ extern NCBI_XCONNECT_EXPORT const char* LOG_LevelStr(ELOG_Level level);
  *  Raw data to log (usually NULL)
  * @param raw_size
  *  Size of the raw data (usually zero)
+ * @param err_code
+ *  Error code of the message
+ * @param err_subcode
+ *  Error subcode of the message
  * @sa
  *  FLOG_Handler, LOG_Create, LOG_WriteInternal
  */
@@ -324,6 +328,8 @@ typedef struct {
     int         line;
     const void* raw_data;
     size_t      raw_size;
+    int         err_code;
+    int         err_subcode;
 } SLOG_Handler;
 
 
@@ -441,6 +447,10 @@ extern NCBI_XCONNECT_EXPORT LOG LOG_Delete(LOG lg);
  *  Raw data to log (can be NULL)
  * @param raw_size
  *  Size of the raw data (can be zero)
+ * @param err_code
+ *  Error code of the message
+ * @param err_subcode
+ *  Error subcode of the message
  * @sa
  *  LOG_Create, ELOG_Level, FLOG_Handler, LOG_WRITE, LOG_DATA
  */
@@ -452,8 +462,10 @@ extern NCBI_XCONNECT_EXPORT void LOG_WriteInternal
  int         line,  
  const char* message,
  const void* raw_data,
- size_t      raw_size
- );
+ size_t      raw_size,
+ int         err_code,
+ int         err_subcode
+);
 
 
 
