@@ -1,4 +1,4 @@
-/*  $Id: ncbi_heapmgr.c,v 6.39 2007/04/20 01:55:30 kazimird Exp $
+/*  $Id: ncbi_heapmgr.c,v 6.43 2008/02/21 15:26:12 kazimird Exp $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -116,6 +116,8 @@
 #include <stdlib.h>
 #include <string.h>
 
+#define NCBI_USE_ERRCODE_X   Connect_HeapMgr
+
 #if defined(NCBI_OS_MSWIN)  &&  defined(_WIN64)
 /* Disable ptr->long conversion warning (even on explicit cast!) */
 #  pragma warning (disable : 4311)
@@ -189,9 +191,10 @@ HEAP HEAP_Create(void* base,       TNCBI_Size   size,
     if (!base != !size)
         return 0;
     if (size  &&  size < _HEAP_ALIGNMENT) {
-        CORE_LOGF(eLOG_Error,
-                  ("Heap Create: Storage too small: provided %u, required %u+",
-                   size, _HEAP_ALIGNMENT));
+        CORE_LOGF_X(1, eLOG_Error,
+                    ("Heap Create: Storage too small: "
+                     "provided %u, required %u+",
+                     size, _HEAP_ALIGNMENT));
         return 0;
     }
     if (!(heap = (HEAP) malloc(sizeof(*heap))))
@@ -210,8 +213,9 @@ HEAP HEAP_Create(void* base,       TNCBI_Size   size,
         SHEAP_HeapBlock* b = heap->base;
         /* Reformat the pre-allocated heap */
         if (_HEAP_ALIGN(base, sizeof(SHEAP_Block)) != (unsigned long) base) {
-            CORE_LOGF(eLOG_Warning,
-                     ("Heap Create: Unaligned base (0x%08lX)", (long) base));
+            CORE_LOGF_X(2, eLOG_Warning,
+                        ("Heap Create: Unaligned base (0x%08lX)",
+                         (long) base));
         }
         b->head.flag = HEAP_FREE | HEAP_LAST;
         b->head.size = size;
@@ -230,16 +234,17 @@ HEAP HEAP_AttachFast(const void* base, TNCBI_Size size, int serial)
     if (!base != !size  ||  !(heap = (HEAP) calloc(1, sizeof(*heap))))
         return 0;
     if (_HEAP_ALIGN(base, sizeof(SHEAP_Block)) != (unsigned long) base) {
-        CORE_LOGF(eLOG_Warning,
-                  ("Heap Attach: Unaligned base (0x%08lX)", (long) base));
+        CORE_LOGF_X(3, eLOG_Warning,
+                    ("Heap Attach: Unaligned base (0x%08lX)", (long) base));
     }
     heap->base   = (SHEAP_HeapBlock*) base;
     heap->size   = HEAP_ALIGN(size) >> _HEAP_ALIGNSHIFT;
     heap->serial = serial;
     if (size != heap->size << _HEAP_ALIGNSHIFT) {
-        CORE_LOGF(eLOG_Warning,
-                  ("Heap Attach: Heap size alignment (%u->%u) can result in"
-                   " garbage in data", size, heap->size << _HEAP_ALIGNSHIFT));
+        CORE_LOGF_X(4, eLOG_Warning,
+                    ("Heap Attach: Heap size alignment (%u->%u) "
+                     "can result in garbage in data",
+                     size, heap->size << _HEAP_ALIGNSHIFT));
     }
     return heap;
 }
@@ -253,10 +258,10 @@ HEAP HEAP_Attach(const void* base, int serial)
         const SHEAP_HeapBlock* b = (const SHEAP_HeapBlock*) base;
         for (;;) {
             if (!HEAP_ISUSED(b)  &&  !HEAP_ISFREE(b)) {
-                CORE_LOGF(eLOG_Error,
-                          ("Heap Attach: Heap corrupt @%u (0x%08X, %u)",
-                           HEAP_INDEX(b, (SHEAP_HeapBlock*) base),
-                           b->head.flag, b->head.size));
+                CORE_LOGF_X(5, eLOG_Error,
+                            ("Heap Attach: Heap corrupt @%u (0x%08X, %u)",
+                             HEAP_INDEX(b, (SHEAP_HeapBlock*) base),
+                             b->head.flag, b->head.size));
                 return 0;
             }
             size += b->head.size;
@@ -404,14 +409,14 @@ static SHEAP_Block* s_HEAP_Alloc(HEAP heap, TNCBI_Size size, int/*bool*/ fast)
     char _id[32];
 
     if (!heap) {
-        CORE_LOG(eLOG_Warning, "Heap Alloc: NULL heap");
+        CORE_LOG_X(6, eLOG_Warning, "Heap Alloc: NULL heap");
         return 0;
     }
     assert(!heap->base == !heap->size);
 
     if (!heap->chunk) {
-        CORE_LOGF(eLOG_Error,
-                  ("Heap Alloc%s: Heap read-only", s_HEAP_Id(_id, heap)));
+        CORE_LOGF_X(7, eLOG_Error,
+                    ("Heap Alloc%s: Heap read-only", s_HEAP_Id(_id, heap)));
         return 0;
     }
     if (size < 1)
@@ -425,11 +430,12 @@ static SHEAP_Block* s_HEAP_Alloc(HEAP heap, TNCBI_Size size, int/*bool*/ fast)
         b = f;
         do {
             if (!HEAP_ISFREE(b)) {
-                CORE_LOGF(eLOG_Error,
-                          ("Heap Alloc%s: Heap%s corrupt @%u/%u (0x%08X, %u)",
-                           s_HEAP_Id(_id, heap), b == f ? " header" : "",
-                           HEAP_INDEX(b, heap->base), heap->size,
-                           b->head.flag, b->head.size));
+                CORE_LOGF_X(8, eLOG_Error,
+                            ("Heap Alloc%s: Heap%s corrupt "
+                             "@%u/%u (0x%08X, %u)",
+                             s_HEAP_Id(_id, heap), b == f ? " header" : "",
+                             HEAP_INDEX(b, heap->base), heap->size,
+                             b->head.flag, b->head.size));
                 return 0;
             }
             if (b->head.size >= size)
@@ -445,17 +451,20 @@ static SHEAP_Block* s_HEAP_Alloc(HEAP heap, TNCBI_Size size, int/*bool*/ fast)
     else if (!heap->resize)
         return 0;
     else {
-        TNCBI_Size hsize = ((size + (heap->size << _HEAP_ALIGNSHIFT)
-                             + heap->chunk - 1) / heap->chunk) * heap->chunk;
+        TNCBI_Size dsize = heap->size << _HEAP_ALIGNSHIFT;
+        TNCBI_Size hsize = ((dsize + size + heap->chunk - 1)
+                            / heap->chunk) * heap->chunk;
         SHEAP_HeapBlock* base = (SHEAP_HeapBlock*)
             heap->resize(heap->base, (size_t) hsize, heap->arg);
         if (_HEAP_ALIGN(base, sizeof(SHEAP_Block)) != (unsigned long) base) {
-            CORE_LOGF(eLOG_Warning,
-                      ("Heap Alloc%s: Unaligned base (0x%08lX)",
-                       s_HEAP_Id(_id, heap), (long) base));
+            CORE_LOGF_X(9, eLOG_Warning,
+                        ("Heap Alloc%s: Unaligned base (0x%08lX)",
+                         s_HEAP_Id(_id, heap), (long) base));
         }
         if (!base)
             return 0;
+        dsize = hsize - dsize;
+        memset(base + heap->size, 0, (size_t) dsize); /* security */
 
         b = base + heap->last;
         if (!heap->base) {
@@ -472,7 +481,7 @@ static SHEAP_Block* s_HEAP_Alloc(HEAP heap, TNCBI_Size size, int/*bool*/ fast)
                 /* New block is at the very top on the heap */
                 b = base + heap->size;
                 b->head.flag = HEAP_FREE | HEAP_LAST;
-                b->head.size = hsize - (heap->size << _HEAP_ALIGNSHIFT);
+                b->head.size = dsize;
                 heap->last   = heap->size;
                 if (heap->free < heap->size) {
                     assert(HEAP_ISFREE(base + heap->free));
@@ -484,11 +493,11 @@ static SHEAP_Block* s_HEAP_Alloc(HEAP heap, TNCBI_Size size, int/*bool*/ fast)
                     b->prevfree = heap->size;
                     b->nextfree = heap->size;
                 }
-                heap->free  = heap->size;
+                heap->free = heap->size;
             } else {
                 /* Extend last free block */
                 assert(HEAP_ISFREE(b));
-                b->head.size += hsize - (heap->size << _HEAP_ALIGNSHIFT);
+                b->head.size += dsize;
             }
         }
         heap->base = base;
@@ -586,14 +595,14 @@ void HEAP_Free(HEAP heap, SHEAP_Block* ptr)
     char _id[32];
 
     if (!heap) {
-        CORE_LOG(eLOG_Warning, "Heap Free: NULL heap");
+        CORE_LOG_X(10, eLOG_Warning, "Heap Free: NULL heap");
         return;
     }
     assert(!heap->base == !heap->size);
 
     if (!heap->chunk) {
-        CORE_LOGF(eLOG_Error,
-                  ("Heap Free%s: Heap read-only", s_HEAP_Id(_id, heap)));
+        CORE_LOGF_X(11, eLOG_Error,
+                    ("Heap Free%s: Heap read-only", s_HEAP_Id(_id, heap)));
         return;
     }
     if (!ptr)
@@ -606,14 +615,14 @@ void HEAP_Free(HEAP heap, SHEAP_Block* ptr)
             if (HEAP_ISUSED(b)) {
                 s_HEAP_Free(heap, p, b);
             } else if (HEAP_ISFREE(b)) {
-                CORE_LOGF(eLOG_Warning,
-                          ("Heap Free%s: Freeing free block @%u",
-                           s_HEAP_Id(_id, heap), HEAP_INDEX(b, heap->base)));
+                CORE_LOGF_X(12, eLOG_Warning,
+                            ("Heap Free%s: Freeing free block @%u",
+                             s_HEAP_Id(_id, heap), HEAP_INDEX(b, heap->base)));
             } else {
-                CORE_LOGF(eLOG_Error,
-                          ("Heap Free%s: Heap corrupt @%u/%u (0x%08X, %u)",
-                           s_HEAP_Id(_id, heap), HEAP_INDEX(b, heap->base),
-                           heap->size, b->head.flag, b->head.size));
+                CORE_LOGF_X(13, eLOG_Error,
+                            ("Heap Free%s: Heap corrupt @%u/%u (0x%08X, %u)",
+                             s_HEAP_Id(_id, heap), HEAP_INDEX(b, heap->base),
+                             heap->size, b->head.flag, b->head.size));
             }
             return;
         }
@@ -621,8 +630,8 @@ void HEAP_Free(HEAP heap, SHEAP_Block* ptr)
         b = HEAP_NEXT(b);
     }
 
-    CORE_LOGF(eLOG_Error,
-              ("Heap Free%s: Block not found", s_HEAP_Id(_id, heap)));
+    CORE_LOGF_X(14, eLOG_Error,
+                ("Heap Free%s: Block not found", s_HEAP_Id(_id, heap)));
 }
 
 
@@ -632,14 +641,14 @@ void HEAP_FreeFast(HEAP heap, SHEAP_Block* ptr, const SHEAP_Block* prev)
     char _id[32];
 
     if (!heap) {
-        CORE_LOG(eLOG_Warning, "Heap Free: NULL heap");
+        CORE_LOG_X(15, eLOG_Warning, "Heap Free: NULL heap");
         return;
     }
     assert(!heap->base == !heap->size);
 
     if (!heap->chunk) {
-        CORE_LOGF(eLOG_Error,
-                  ("Heap Free%s: Heap read-only", s_HEAP_Id(_id, heap)));
+        CORE_LOGF_X(16, eLOG_Error,
+                    ("Heap Free%s: Heap read-only", s_HEAP_Id(_id, heap)));
         return;
     }
     if (!ptr)
@@ -649,19 +658,19 @@ void HEAP_FreeFast(HEAP heap, SHEAP_Block* ptr, const SHEAP_Block* prev)
     b = (SHEAP_HeapBlock*) ptr;
     if (!s_HEAP_fast) {
         if (b < heap->base  ||  b >= heap->base + heap->size) {
-            CORE_LOGF(eLOG_Error,
-                      ("Heap Free%s: Alien block", s_HEAP_Id(_id, heap)));
+            CORE_LOGF_X(17, eLOG_Error,
+                        ("Heap Free%s: Alien block", s_HEAP_Id(_id, heap)));
             return;
         } else if ((!p  &&  b != heap->base)  ||
                    ( p  &&  (p < heap->base  ||  HEAP_NEXT(p) != b))) {
-            CORE_LOGF(eLOG_Warning,
-                      ("Heap Free%s: Invalid hint", s_HEAP_Id(_id, heap)));
+            CORE_LOGF_X(18, eLOG_Warning,
+                        ("Heap Free%s: Invalid hint", s_HEAP_Id(_id, heap)));
             HEAP_Free(heap, ptr);
             return;
         } else if (HEAP_ISFREE(b)) {
-            CORE_LOGF(eLOG_Warning,
-                      ("Heap Free%s: Freeing free block @%u",
-                       s_HEAP_Id(_id, heap), HEAP_INDEX(b, heap->base)));
+            CORE_LOGF_X(19, eLOG_Warning,
+                        ("Heap Free%s: Freeing free block @%u",
+                         s_HEAP_Id(_id, heap), HEAP_INDEX(b, heap->base)));
             return;
         }
     }
@@ -685,9 +694,9 @@ static SHEAP_Block* s_HEAP_Walk(const HEAP heap, const SHEAP_Block* ptr)
                 if (s_HEAP_newalk) {
                     if (HEAP_ISUSED(b)  &&  heap->chunk/*RW heap*/  &&
                         heap->base + heap->free == b) {
-                        CORE_LOGF(eLOG_Warning,
-                                  ("Heap Walk%s: Used block @ free ptr %u",
-                                   s_HEAP_Id(_id, heap), heap->free));
+                        CORE_LOGF_X(20, eLOG_Warning,
+                                    ("Heap Walk%s: Used block @ free ptr %u",
+                                     s_HEAP_Id(_id, heap), heap->free));
                     } else if (HEAP_ISFREE(b)  &&
                                (b->prevfree >= heap->size  ||
                                 b->nextfree >= heap->size  ||
@@ -696,26 +705,28 @@ static SHEAP_Block* s_HEAP_Walk(const HEAP heap, const SHEAP_Block* ptr)
                                 (b->prevfree != b->nextfree
                                  && (heap->base + b->prevfree == b  ||
                                      heap->base + b->nextfree == b)))) {
-                        CORE_LOGF(eLOG_Warning,
-                                  ("Heap Walk%s: Free list corrupt @%u/%u"
-                                   " (%u, <-%u, %u->)", s_HEAP_Id(_id,heap),
-                                   HEAP_INDEX(b, heap->base), heap->size,
-                                   b->head.size, b->prevfree, b->nextfree));
+                        CORE_LOGF_X(21, eLOG_Warning,
+                                    ("Heap Walk%s: Free list corrupt @%u/%u"
+                                     " (%u, <-%u, %u->)", s_HEAP_Id(_id,heap),
+                                     HEAP_INDEX(b, heap->base), heap->size,
+                                     b->head.size, b->prevfree, b->nextfree));
                     }
                 }
                 /* Block 'b' seems okay for walking onto, but... */
                 if (!p)
                     return &b->head;
                 if (HEAP_ISLAST(p)) {
-                    CORE_LOGF(eLOG_Error,
-                              ("Heap Walk%s: Misplaced last block @%u",
-                               s_HEAP_Id(_id,heap), HEAP_INDEX(p,heap->base)));
+                    CORE_LOGF_X(22, eLOG_Error,
+                                ("Heap Walk%s: Misplaced last block @%u",
+                                 s_HEAP_Id(_id,heap),
+                                 HEAP_INDEX(p,heap->base)));
                 } else if (s_HEAP_newalk  &&  heap->chunk/*RW heap*/  &&
                            HEAP_ISLAST(b)  &&  heap->base + heap->last != b) {
-                    CORE_LOGF(eLOG_Error,
-                              ("Heap Walk%s: Last block @%u not @ last ptr %u",
-                               s_HEAP_Id(_id, heap), HEAP_INDEX(b, heap->base),
-                               heap->last));
+                    CORE_LOGF_X(23, eLOG_Error,
+                                ("Heap Walk%s: Last block @%u "
+                                 "not @ last ptr %u",
+                                 s_HEAP_Id(_id, heap),
+                                 HEAP_INDEX(b, heap->base), heap->last));
                 } else if (HEAP_ISFREE(p)  &&  HEAP_ISFREE(b)) {
                     const SHEAP_HeapBlock* c = heap->base;
                     while (c < p) {
@@ -725,28 +736,31 @@ static SHEAP_Block* s_HEAP_Walk(const HEAP heap, const SHEAP_Block* ptr)
                     }
                     if (c < p)
                         return &b->head;
-                    CORE_LOGF(eLOG_Error,
-                              ("Heap Walk%s: Adjacent free blocks @%u and @%u",
-                               s_HEAP_Id(_id, heap), HEAP_INDEX(p, heap->base),
-                               HEAP_INDEX(b, heap->base)));
+                    CORE_LOGF_X(24, eLOG_Error,
+                                ("Heap Walk%s: Adjacent free blocks "
+                                 "@%u and @%u",
+                                 s_HEAP_Id(_id, heap),
+                                 HEAP_INDEX(p, heap->base),
+                                 HEAP_INDEX(b, heap->base)));
                 } else
                     return &b->head;
             } else {
-                CORE_LOGF(eLOG_Error,
-                          ("Heap Walk%s: Heap corrupt @%u/%u (0x%08X, %u)",
-                           s_HEAP_Id(_id, heap), HEAP_INDEX(b, heap->base),
-                           heap->size, b->head.flag, b->head.size));
+                CORE_LOGF_X(25, eLOG_Error,
+                            ("Heap Walk%s: Heap corrupt @%u/%u (0x%08X, %u)",
+                             s_HEAP_Id(_id, heap), HEAP_INDEX(b, heap->base),
+                             heap->size, b->head.flag, b->head.size));
             }
         } else if (b > heap->base + heap->size) {
-            CORE_LOGF(eLOG_Error,
-                      ("Heap Walk%s: Heap corrupt", s_HEAP_Id(_id, heap)));
+            CORE_LOGF_X(26, eLOG_Error,
+                        ("Heap Walk%s: Heap corrupt", s_HEAP_Id(_id, heap)));
         } else if (b  &&  !HEAP_ISLAST(p)) {
-            CORE_LOGF(eLOG_Error,
-                      ("Heap Walk%s: Last block lost", s_HEAP_Id(_id, heap)));
+            CORE_LOGF_X(27, eLOG_Error,
+                        ("Heap Walk%s: Last block lost",
+                         s_HEAP_Id(_id, heap)));
         }
     } else {
-        CORE_LOGF(eLOG_Error,
-                  ("Heap Walk%s: Alien pointer", s_HEAP_Id(_id, heap)));
+        CORE_LOGF_X(28, eLOG_Error,
+                    ("Heap Walk%s: Alien pointer", s_HEAP_Id(_id, heap)));
     }
     return 0;
 }
@@ -755,7 +769,7 @@ static SHEAP_Block* s_HEAP_Walk(const HEAP heap, const SHEAP_Block* ptr)
 SHEAP_Block* HEAP_Walk(const HEAP heap, const SHEAP_Block* ptr)
 {
     if (!heap) {
-        CORE_LOG(eLOG_Warning, "Heap Walk: NULL heap");
+        CORE_LOG_X(29, eLOG_Warning, "Heap Walk: NULL heap");
         return 0;
     }
     assert(!heap->base == !heap->size);
@@ -782,8 +796,8 @@ HEAP HEAP_Trim(HEAP heap)
     assert(!heap->base == !heap->size);
  
    if (!heap->chunk) {
-        CORE_LOGF(eLOG_Error,
-                  ("Heap Trim%s: Heap read-only", s_HEAP_Id(_id, heap)));
+        CORE_LOGF_X(30, eLOG_Error,
+                    ("Heap Trim%s: Heap read-only", s_HEAP_Id(_id, heap)));
         return 0;
     }
 
@@ -811,9 +825,9 @@ HEAP HEAP_Trim(HEAP heap)
         else if (!base)
             return 0;
         if (_HEAP_ALIGN(base, sizeof(SHEAP_Block)) != (unsigned long) base) {
-            CORE_LOGF(eLOG_Warning,
-                      ("Heap Trim%s: Unaligned base (0x%08lX)",
-                       s_HEAP_Id(_id, heap), (long) base));
+            CORE_LOGF_X(31, eLOG_Warning,
+                        ("Heap Trim%s: Unaligned base (0x%08lX)",
+                         s_HEAP_Id(_id, heap), (long) base));
         }
         prev = HEAP_INDEX(f, heap->base);
         heap->base = base;
@@ -830,8 +844,8 @@ HEAP HEAP_Trim(HEAP heap)
         assert(hsize == heap->size << _HEAP_ALIGNSHIFT);
         assert(hsize % heap->chunk == 0);
     } else if (hsize != heap->size << _HEAP_ALIGNSHIFT) {
-        CORE_LOGF(eLOG_Error,
-                  ("Heap Trim%s: Heap not trimmable", s_HEAP_Id(_id, heap)));
+        CORE_LOGF_X(32, eLOG_Error,
+                    ("Heap Trim%s: Heap not trimmable", s_HEAP_Id(_id, heap)));
     }
 
     assert(!heap->base == !heap->size);
@@ -894,12 +908,15 @@ void HEAP_Detach(HEAP heap)
 
 void HEAP_Destroy(HEAP heap)
 {
+    char _id[32];
+
     if (!heap)
         return;
     assert(!heap->base == !heap->size);
-    if (!heap->chunk  &&  !heap->refc)
-        CORE_LOG(eLOG_Error, "Heap Destroy: Heap read-only");
-    else if (heap->resize/*NB: NULL for heap copies*/)
+    if (!heap->chunk  &&  !heap->refc) {
+        CORE_LOGF_X(33, eLOG_Error,
+                    ("Heap Destroy%s: Heap read-only", s_HEAP_Id(_id, heap)));
+    } else if (heap->resize/*NB: NULL for heap copies*/)
         verify(heap->resize(heap->base, 0, heap->arg) == 0);
     HEAP_Detach(heap);
 }
