@@ -1,4 +1,4 @@
-/*  $Id: asn_connection.c,v 1.8 2004/11/23 16:15:29 lavr Exp $
+/*  $Id: asn_connection.c,v 1.9 2007/10/17 15:25:44 kazimird Exp $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -32,6 +32,10 @@
 
 #include <ctools/asn_connection.h>
 #include "../connect/ncbi_priv.h"
+#include "error_codes.h"
+
+
+#define NCBI_USE_ERRCODE_X   Ctools_ASN
 
 
 #ifdef __cplusplus
@@ -70,7 +74,7 @@ static void s_CloseAsnConn(CONN conn, ECONN_Callback type, void* data)
     struct SAsnConn_Cbdata* cbdata = (struct SAsnConn_Cbdata*) data;
 
     assert(type == eCONN_OnClose && cbdata && cbdata->ptr);
-    CONN_SetCallback(conn, type, &cbdata->cb, 0); 
+    CONN_SetCallback(conn, type, &cbdata->cb, 0);
     AsnIoFree(cbdata->ptr, 0/*not a file - don't close*/);
     if ( cbdata->cb.func )
         (*cbdata->cb.func)(conn, type, cbdata->cb.data);
@@ -91,8 +95,8 @@ static void s_SetAsnConn_CloseCb(CONN conn, AsnIoPtr ptr)
         cb.data = cbdata;
         CONN_SetCallback(conn, eCONN_OnClose, &cb, &cbdata->cb);
     } else
-        CORE_LOG(eLOG_Error,
-                 "Cannot create cleanup callback for ASN conn-based stream");
+        CORE_LOG_X(1, eLOG_Error,
+                   "Cannot create cleanup callback for ASN conn-based stream");
 }
 
 
@@ -165,35 +169,3 @@ CONN CreateAsnConn_Service(const char*     service,
     return CreateAsnConn_ServiceEx(service, input_fmt, input,
                                    output_fmt, output, fSERV_Any, 0, 0);
 }
-
-
-/*
- * --------------------------------------------------------------------------
- * $Log: asn_connection.c,v $
- * Revision 1.8  2004/11/23 16:15:29  lavr
- * -<connect/ncbi_service_connector.h> now included from <ctools/asn_connectionh>
- *
- * Revision 1.7  2004/03/23 02:29:19  lavr
- * Remove redundant inits in I/O callbacks
- *
- * Revision 1.6  2004/02/23 15:23:50  lavr
- * New (last) parameter "how" added in CONN_Write() API call
- *
- * Revision 1.5  2003/11/13 16:01:31  lavr
- * Included headers revised
- *
- * Revision 1.4  2002/08/07 16:38:18  lavr
- * EIO_ReadMethod enums changed accordingly; log moved to end
- *
- * Revision 1.3  2001/09/24 20:32:44  lavr
- * +SSERVICE_Extra* parameter in CreateAsnConn_ServiceEx()
- *
- * Revision 1.2  2001/06/29 14:04:17  lavr
- * Close callback removes itself when called; fixes not to add callbacks
- * in CreateAsnConn_ServiceEx, because they are already there!
- *
- * Revision 1.1  2001/06/28 21:58:23  lavr
- * Initial revision
- *
- * ==========================================================================
- */
