@@ -29,7 +29,7 @@
 *   
 * Version Creation Date: 4/1/91
 *
-* $Revision: 6.8 $
+* $Revision: 6.12 $
 *
 * File Description:  Object manager interface for type Pubdesc from
 *                    NCBI-Sequence.  This is separate to avoid typedef
@@ -45,6 +45,19 @@
 * -------  ----------  -----------------------------------------------------
 *
 * $Log: objpubd.h,v $
+* Revision 6.12  2007/12/04 17:50:55  kans
+* added MI_TECH_tsa
+*
+* Revision 6.11  2005/12/29 13:46:18  bollin
+* added PubdescContentMatch function
+*
+* Revision 6.10  2005/05/24 19:13:47  bollin
+* removed PubdescMatch function - was conflicting with local versions elsewhere.
+* Function is now a local function in desktop\seqsub.c
+*
+* Revision 6.9  2005/05/23 12:59:31  bollin
+* added PubdescMatch function
+*
 * Revision 6.8  2004/12/08 20:20:34  kans
 * changed MI_TECH_composite to MI_TECH_composite_wgs_htgs
 *
@@ -139,6 +152,8 @@ NLM_EXTERN Boolean    LIBCALL PubdescAsnWrite PROTO((PubdescPtr pdp, AsnIoPtr ai
 NLM_EXTERN PubdescPtr LIBCALL PubdescAsnRead PROTO((AsnIoPtr aip, AsnTypePtr atp));
 NLM_EXTERN PubdescPtr LIBCALL PubdescFree PROTO((PubdescPtr pdp));
 
+NLM_EXTERN Boolean LIBCALL PubdescContentMatch (PubdescPtr pdp1, PubdescPtr pdp2);
+
 typedef ValNode Numbering, FAR *NumberingPtr;
 
 /*****************************************************************************
@@ -244,6 +259,7 @@ typedef struct molinfo {
 #define MI_TECH_wgs 20       /* Whole Genome Shotgun */
 #define MI_TECH_barcode 21   /* Barcode of Life Project */
 #define MI_TECH_composite_wgs_htgs 22   /* Assembly/Scaffold composite of techniques */
+#define MI_TECH_tsa 23       /* Transcriptome Shotgun Assembly */
 #define MI_TECH_other 255           /* doesnt' fit anything */
 
 NLM_EXTERN MolInfoPtr LIBCALL MolInfoNew PROTO((void));
